@@ -1,3 +1,4 @@
+from cgi import test
 import json
 import os
 import signal
@@ -24,6 +25,15 @@ class SynDB(object):
         if self.dthread is not None:
             self.dthread.join()
 
+    def __version__(self):
+        return "1.9"
+
+    def __repr__(self):
+        return str(self.db)
+
+    def __str__(self):
+        return str(self.db)
+
     def load(self , location, auto_dump):
        self.loco = location
        self.auto_dump = auto_dump
@@ -157,4 +167,13 @@ class SynDB(object):
             self._autodump()
             return True
         else:
+            return False
+
+    def set_two(self, key, value_name, value):
+        try:
+            data = {value_name: value}
+            self.db[key] = data
+            self._autodump()
+            return True
+        except:
             return False
\ No newline at end of file
